@@ -5,16 +5,18 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Functional;
 
 use Doctrine\ORM\EntityNotFoundException;
+use Doctrine\ORM\Exception\EntityIdentityCollisionException;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\ORMInvalidArgumentException;
 use Doctrine\ORM\PersistentCollection;
+use Doctrine\ORM\Proxy\InternalProxy;
 use Doctrine\ORM\Query;
 use Doctrine\ORM\UnitOfWork;
-use Doctrine\Persistence\Proxy;
 use Doctrine\Tests\IterableTester;
 use Doctrine\Tests\Models\CMS\CmsAddress;
 use Doctrine\Tests\Models\CMS\CmsArticle;
 use Doctrine\Tests\Models\CMS\CmsComment;
+use Doctrine\Tests\Models\CMS\CmsGroup;
 use Doctrine\Tests\Models\CMS\CmsPhonenumber;
 use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\OrmFunctionalTestCase;
@@ -144,7 +146,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         // Address has been eager-loaded because it cant be lazy
         self::assertInstanceOf(CmsAddress::class, $user2->address);
-        self::assertNotInstanceOf(Proxy::class, $user2->address);
+        self::assertFalse($this->isUninitializedObject($user2->address));
     }
 
     /** @group DDC-1230 */
@@ -515,42 +517,76 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         self::assertEquals(4, $gblanco2->getPhonenumbers()->count());
     }
 
-    public function testSetSetAssociationWithGetReference(): void
+    public function testSetToOneAssociationWithGetReference(): void
     {
         $user           = new CmsUser();
         $user->name     = 'Guilherme';
         $user->username = 'gblanco';
         $user->status   = 'developer';
         $this->_em->persist($user);
-
-        $address          = new CmsAddress();
-        $address->country = 'Germany';
-        $address->city    = 'Berlin';
-        $address->zip     = '12345';
-        $this->_em->persist($address);
-
-        $this->_em->flush();
-        $this->_em->clear(CmsAddress::class);
-
-        self::assertFalse($this->_em->contains($address));
-        self::assertTrue($this->_em->contains($user));
-
-        // Assume we only got the identifier of the address and now want to attach
-        // that address to the user without actually loading it, using getReference().
-        $addressRef = $this->_em->getReference(CmsAddress::class, $address->getId());
-
-        $user->setAddress($addressRef); // Ugh! Initializes address 'cause of $address->setUser($user)!
-
         $this->_em->flush();
         $this->_em->clear();
 
+        // Assume we only got the identifier of the user and now want to attach
+        // the article to the user without actually loading it, using getReference().
+        $userRef = $this->_em->getReference(CmsUser::class, $user->getId());
+        self::assertTrue($this->isUninitializedObject($userRef));
+
+        $article        = new CmsArticle();
+        $article->topic = 'topic';
+        $article->text  = 'text';
+        $article->setAuthor($userRef);
+
+        $this->_em->persist($article);
+        $this->_em->flush();
+
+        self::assertFalse($userRef->__isInitialized());
+
+        $this->_em->clear();
+
         // Check with a fresh load that the association is indeed there
-        $query   = $this->_em->createQuery("select u, a from Doctrine\Tests\Models\CMS\CmsUser u join u.address a where u.username='gblanco'");
+        $query   = $this->_em->createQuery("select u, a from Doctrine\Tests\Models\CMS\CmsUser u join u.articles a where u.username='gblanco'");
         $gblanco = $query->getSingleResult();
 
         self::assertInstanceOf(CmsUser::class, $gblanco);
-        self::assertInstanceOf(CmsAddress::class, $gblanco->getAddress());
-        self::assertEquals('Berlin', $gblanco->getAddress()->getCity());
+        self::assertInstanceOf(CmsArticle::class, $gblanco->articles[0]);
+        self::assertSame($article->id, $gblanco->articles[0]->id);
+        self::assertSame('text', $gblanco->articles[0]->text);
+    }
+
+    public function testAddToToManyAssociationWithGetReference(): void
+    {
+        $group       = new CmsGroup();
+        $group->name = 'admins';
+        $this->_em->persist($group);
+        $this->_em->flush();
+        $this->_em->clear();
+
+        // Assume we only got the identifier of the user and now want to attach
+        // the article to the user without actually loading it, using getReference().
+        $groupRef = $this->_em->getReference(CmsGroup::class, $group->id);
+        self::assertTrue($this->isUninitializedObject($groupRef));
+
+        $user           = new CmsUser();
+        $user->name     = 'Guilherme';
+        $user->username = 'gblanco';
+        $user->groups->add($groupRef);
+
+        $this->_em->persist($user);
+        $this->_em->flush();
+
+        self::assertFalse($groupRef->__isInitialized());
+
+        $this->_em->clear();
+
+        // Check with a fresh load that the association is indeed there
+        $query   = $this->_em->createQuery("select u, a from Doctrine\Tests\Models\CMS\CmsUser u join u.groups a where u.username='gblanco'");
+        $gblanco = $query->getSingleResult();
+
+        self::assertInstanceOf(CmsUser::class, $gblanco);
+        self::assertInstanceOf(CmsGroup::class, $gblanco->groups[0]);
+        self::assertSame($group->id, $gblanco->groups[0]->id);
+        self::assertSame('admins', $gblanco->groups[0]->name);
     }
 
     public function testOneToManyCascadeRemove(): void
@@ -707,9 +743,8 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
                 ->setParameter('user', $userRef)
                 ->getSingleResult();
 
-        self::assertInstanceOf(Proxy::class, $address2->getUser());
         self::assertTrue($userRef === $address2->getUser());
-        self::assertFalse($userRef->__isInitialized());
+        self::assertTrue($this->isUninitializedObject($userRef));
         self::assertEquals('Germany', $address2->country);
         self::assertEquals('Berlin', $address2->city);
         self::assertEquals('12345', $address2->zip);
@@ -1006,8 +1041,8 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
                              ->setParameter(1, $article->id)
                              ->setFetchMode(CmsArticle::class, 'user', ClassMetadata::FETCH_EAGER)
                              ->getSingleResult();
-        self::assertInstanceOf(Proxy::class, $article->user, 'It IS a proxy, ...');
-        self::assertTrue($article->user->__isInitialized(), '...but its initialized!');
+        self::assertInstanceOf(InternalProxy::class, $article->user, 'It IS a proxy, ...');
+        self::assertFalse($this->isUninitializedObject($article->user), '...but its initialized!');
         $this->assertQueryCount(2);
     }
 
@@ -1291,4 +1326,35 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $this->_em->flush();
     }
+
+    public function testItThrowsWhenReferenceUsesIdAssignedByDatabase(): void
+    {
+        $this->_em->getConfiguration()->setRejectIdCollisionInIdentityMap(true);
+
+        $user           = new CmsUser();
+        $user->name     = 'test';
+        $user->username = 'test';
+        $this->_em->persist($user);
+        $this->_em->flush();
+
+        // Obtain a reference object for the next ID. This is a user error - references
+        // should be fetched only for existing IDs
+        $ref = $this->_em->getReference(CmsUser::class, $user->id + 1);
+
+        $user2           = new CmsUser();
+        $user2->name     = 'test2';
+        $user2->username = 'test2';
+
+        // Now the database will assign an ID to the $user2 entity, but that place
+        // in the identity map is already taken by user error.
+        $this->expectException(EntityIdentityCollisionException::class);
+        $this->expectExceptionMessageMatches('/another object .* was already present for the same ID/');
+
+        // depending on ID generation strategy, the ID may be asssigned already here
+        // and the entity be put in the identity map
+        $this->_em->persist($user2);
+
+        // post insert IDs will be assigned during flush
+        $this->_em->flush();
+    }
 }
