@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Mapping;
 
+use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 use Doctrine\ORM\EntityRepository;
 use Doctrine\ORM\Id\SequenceGenerator as IdSequenceGenerator;
 use Doctrine\ORM\Mapping\ClassMetadata;
@@ -24,11 +25,13 @@ use Doctrine\ORM\Mapping\SequenceGenerator;
 use Doctrine\ORM\Mapping\Table;
 use Doctrine\ORM\Mapping\UniqueConstraint;
 use Doctrine\Persistence\Mapping\RuntimeReflectionService;
+use Doctrine\Tests\Models\Company\CompanyFixContract;
 use Doctrine\Tests\Models\DDC869\DDC869ChequePayment;
 use Doctrine\Tests\Models\DDC869\DDC869CreditCardPayment;
 use Doctrine\Tests\Models\DDC869\DDC869Payment;
 use Doctrine\Tests\Models\DDC869\DDC869PaymentRepository;
 use Doctrine\Tests\OrmTestCase;
+use Generator;
 
 use function assert;
 use function serialize;
@@ -36,6 +39,8 @@ use function unserialize;
 
 class BasicInheritanceMappingTest extends OrmTestCase
 {
+    use VerifyDeprecations;
+
     /** @var ClassMetadataFactory */
     private $cmf;
 
@@ -218,6 +223,54 @@ class BasicInheritanceMappingTest extends OrmTestCase
         self::assertArrayHasKey('IDX_MAPPED1_INDEX', $class->table['uniqueConstraints']);
         self::assertArrayHasKey('IDX_MAPPED2_INDEX', $class->table['indexes']);
     }
+
+    /**
+     * @dataProvider invalidHierarchyDeclarationClasses
+     */
+    public function testUndeclaredHierarchyRejection(string $rootEntity, string $childClass): void
+    {
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/pull/10431');
+
+        $this->cmf->getMetadataFor($childClass);
+    }
+
+    public static function invalidHierarchyDeclarationClasses(): Generator
+    {
+        yield 'concrete Entity root and child class, direct inheritance'
+            => [InvalidEntityRoot::class, InvalidEntityRootChild::class];
+
+        yield 'concrete Entity root and abstract child class, direct inheritance'
+            => [InvalidEntityRoot::class, InvalidEntityRootAbstractChild::class];
+
+        yield 'abstract Entity root and concrete child class, direct inheritance'
+            => [InvalidAbstractEntityRoot::class, InvalidAbstractEntityRootChild::class];
+
+        yield 'abstract Entity root and abstract child class, direct inheritance'
+            => [InvalidAbstractEntityRoot::class, InvalidAbstractEntityRootAbstractChild::class];
+
+        yield 'complex example (Entity Root -> Mapped Superclass -> transient class -> Entity)'
+            => [InvalidComplexRoot::class, InvalidComplexEntity::class];
+    }
+
+    /** @group DDC-964 */
+    public function testInvalidOverrideFieldInheritedFromEntity(): void
+    {
+        $cm = $this->cmf->getMetadataFor(CompanyFixContract::class);
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/pull/10470');
+
+        $cm->setAttributeOverride('completed', ['name' => 'other_column_name']);
+    }
+
+    /** @group DDC-964 */
+    public function testInvalidOverrideAssociationInheritedFromEntity(): void
+    {
+        $cm = $this->cmf->getMetadataFor(CompanyFixContract::class);
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/pull/10470');
+
+        $cm->setAssociationOverride('salesPerson', ['inversedBy' => 'other_inversed_by_name']);
+    }
 }
 
 class TransientBaseClass
@@ -438,3 +491,85 @@ class MediumSuperclassEntity extends MediumSuperclassBase
 class SubclassWithRepository extends DDC869Payment
 {
 }
+
+/**
+ * @Entity
+ *
+ * This class misses the DiscriminatorMap declaration
+ */
+class InvalidEntityRoot
+{
+    /**
+     * @Column(type="integer")
+     * @Id
+     * @GeneratedValue(strategy="AUTO")
+     * @var int
+     */
+    public $id;
+}
+
+/** @Entity */
+class InvalidEntityRootChild extends InvalidEntityRoot
+{
+}
+
+/** @Entity */
+abstract class InvalidEntityRootAbstractChild extends InvalidEntityRoot
+{
+}
+
+/**
+ * @Entity
+ *
+ * This class misses the DiscriminatorMap declaration
+ */
+class InvalidAbstractEntityRoot
+{
+    /**
+     * @Column(type="integer")
+     * @Id
+     * @GeneratedValue(strategy="AUTO")
+     * @var int
+     */
+    public $id;
+}
+
+/** @Entity */
+class InvalidAbstractEntityRootChild extends InvalidAbstractEntityRoot
+{
+}
+
+/** @Entity */
+abstract class InvalidAbstractEntityRootAbstractChild extends InvalidAbstractEntityRoot
+{
+}
+
+/**
+ * @Entity
+ *
+ * This class misses the DiscriminatorMap declaration
+ */
+class InvalidComplexRoot
+{
+    /**
+     * @Column(type="integer")
+     * @Id
+     * @GeneratedValue(strategy="AUTO")
+     * @var int
+     */
+    public $id;
+}
+
+/** @MappedSuperclass */
+class InvalidComplexMappedSuperclass extends InvalidComplexRoot
+{
+}
+
+class InvalidComplexTransientClass extends InvalidComplexMappedSuperclass
+{
+}
+
+/** @Entity */
+class InvalidComplexEntity extends InvalidComplexTransientClass
+{
+}
